@@ -1,11 +1,15 @@
-# pylint: skip-file
+# pylint: disable=missing-module-docstring,too-many-instance-attributes,invalid-name
+# pylint: disable=disallowed-name,missing-function-docstring,too-many-locals,too-many-branches
+# pylint: disable=missing-param-doc,missing-type-doc,too-many-arguments,line-too-long
+# pylint: disable=unused-argument
 
 import sys
 import copy
-import progressbar
-import numpy as np
 from heapq import heappush, heappushpop
 from itertools import count
+
+import progressbar
+import numpy as np
 from sklearn.base import BaseEstimator
 
 try:
@@ -115,37 +119,37 @@ class LBM_not_sparse(BaseEstimator):
     @property
     def row_group_membership_probability(self):
         """array_like: Returns the row group membership probabilities"""
-        assert self.trained_successfully_ == True, "Model not trained successfully"
+        assert self.trained_successfully_, "Model not trained successfully"
         return self.alpha_1_
 
     @property
     def column_group_membership_probability(self):
         """array_like: Returns the column group membership probabilities"""
-        assert self.trained_successfully_ == True, "Model not trained successfully"
+        assert self.trained_successfully_, "Model not trained successfully"
         return self.alpha_2_
 
     @property
     def row_labels(self):
         """array_like: Returns the row labels"""
-        assert self.trained_successfully_ == True, "Model not trained successfully"
+        assert self.trained_successfully_, "Model not trained successfully"
         return self.tau_1_.argmax(1)
 
     @property
     def column_labels(self):
         """array_like: Returns the column labels"""
-        assert self.trained_successfully_ == True, "Model not trained successfully"
+        assert self.trained_successfully_, "Model not trained successfully"
         return self.tau_2_.argmax(1)
 
     @property
     def row_predict_proba(self):
         """array_like: Returns the predicted row classes membership probabilities"""
-        assert self.trained_successfully_ == True
+        assert self.trained_successfully_
         return self.tau_1_
 
     @property
     def column_predict_proba(self):
         """array_like: Returns the predicted column classes membership probabilities"""
-        assert self.trained_successfully_ == True, "Model not trained successfully"
+        assert self.trained_successfully_, "Model not trained successfully"
         return self.tau_2_
 
     @property
@@ -158,7 +162,7 @@ class LBM_not_sparse(BaseEstimator):
             "max_iter": self.max_iter,
             "n_init": self.n_init,
             "n_init_total_run": self.n_init_total_run,
-            "n_iter_early_stop": self.n_iter_early_stop,
+            "n_iter_early_stop": self.nb_iter_early_stop,
             "rtol": self.rtol,
             "atol": self.atol,
             "verbosity": self.verbosity,
@@ -174,6 +178,7 @@ class LBM_not_sparse(BaseEstimator):
         return self
 
     def _check_params(self):
+        # pylint: disable=attribute-defined-outside-init
         self._np = np
         self._cupyx = None
         self.loglikelihood_ = -np.inf
@@ -195,7 +200,7 @@ class LBM_not_sparse(BaseEstimator):
             and _DEFAULT_USE_GPU
             and cupy.cuda.is_available()
         ):
-            if self.gpu_index != None:
+            if self.gpu_index is not None:
                 cupy.cuda.Device(self.gpu_index).use()
                 self._np = cupy
                 self._cupyx = cupyx
@@ -210,7 +215,7 @@ class LBM_not_sparse(BaseEstimator):
                     gpu_number = free_idx[0]
                     cupy.cuda.Device(gpu_number).use()
 
-    def score(self, X, y=None):
+    def score(self, X, y=None):  # pylint: disable=unused-argument
         if not hasattr(self, "loglikelihood_"):
             self.fit(X)
         return self.get_ICL()
@@ -222,7 +227,7 @@ class LBM_not_sparse(BaseEstimator):
         float
             value of the ICL criteria.
         """
-        assert self.trained_successfully_ == True, "Model not trained successfully"
+        assert self.trained_successfully_, "Model not trained successfully"
         return (
             self.loglikelihood_
             - (self.n_row_clusters - 1) / 2 * np.log(self._nb_rows)
@@ -232,7 +237,7 @@ class LBM_not_sparse(BaseEstimator):
             * np.log(self._nb_cols * self._nb_rows)
         )
 
-    def fit(self, X, y=None) -> None:
+    def fit(self, X, y=None) -> None:  # pylint: disable=unused-argument
         """Perform co-clustering by direct maximization of graph modularity.
 
         Parameters
@@ -240,6 +245,7 @@ class LBM_not_sparse(BaseEstimator):
         X : numpy matrix or scipy sparse matrix, shape=(n_samples, n_features)
             Matrix to be analyzed
         """
+        # pylint: disable=attribute-defined-outside-init
         self._check_params()
         self.trained_successfully_ = False
         n1, n2 = X.shape
@@ -437,6 +443,7 @@ class LBM_not_sparse(BaseEstimator):
             )
 
         if in_place:
+            # pylint: disable=attribute-defined-outside-init
             self.loglikelihood_ = ll.get() if self.use_gpu else ll
             self.trained_successfully_ = True
             self.pi_ = pi.get() if self.use_gpu else pi
@@ -578,7 +585,7 @@ class LBM_not_sparse(BaseEstimator):
         pi = self._np.random.uniform(0, 2 * nb_ones / (n1 * n2), (nq, nl))
         return (alpha_1.flatten(), alpha_2.flatten(), tau_1, tau_2, pi)
 
-    def __repr__(self):
+    def __repr__(self):  # pylint: disable=signature-differs
         return f"""LBM_not_sparse(
                     n_row_clusters={self.n_row_clusters},
                     n_column_clusters={self.n_column_clusters},
@@ -594,18 +601,20 @@ class LBM_not_sparse(BaseEstimator):
 
     def copy(self):
         """Returns a copy of the model."""
-        model = LBM(
+        model = LBM_not_sparse(
             self.n_row_clusters,
             self.n_column_clusters,
-            self.max_iter,
-            self.n_init,
-            self.n_init_total_run,
-            self.nb_iter_early_stop,
-            self.rtol,
-            self.atol,
-            self.verbosity,
-            self.use_gpu,
+            max_iter=self.max_iter,
+            n_init=self.n_init,
+            n_init_total_run=self.n_init_total_run,
+            n_iter_early_stop=self.nb_iter_early_stop,
+            rtol=self.rtol,
+            atol=self.atol,
+            verbosity=self.verbosity,
+            use_gpu=self.use_gpu,
+            gpu_index=self.gpu_index,
         )
+        # pylint: disable=attribute-defined-outside-init,protected-access
         model._nb_rows = self._nb_rows
         model._nb_cols = self._nb_cols
         model.loglikelihood_ = self.loglikelihood_
