@@ -80,21 +80,21 @@ def _define_parsers():
     input_grp.add_argument(
         "-gpu",
         "--use_gpu",
-        help="specify if a GPU should be used.",
+        help="specifies whether a GPU should be used.",
         default=_DEFAULT_USE_GPU,
         type=bool,
     )
     input_grp.add_argument(
         "-idgpu",
         "--gpu_index",
-        help="specify the gpu index if needed.",
+        help="specifies the GPU index if needed.",
         default=None,
         type=bool,
     )
     input_grp.add_argument(
         "-s",
         "--symmetric",
-        help="specify if the adajacency matrix is symmetric. For sbm only",
+        help="specifies whether the adajacency matrix is symmetric. For SBM only",
         default=False,
     )
     input_grp.add_argument(
@@ -192,14 +192,14 @@ def _define_parsers():
             param_grp.add_argument(
                 "-s",
                 "--symmetric",
-                help="Specify if the adajacency matrix is symmetric",
+                help="Specifies whether the adjacency matrix is symmetric",
                 default=False,
                 # type=bool,
             )
         param_grp.add_argument(
             "-niter",
             "--max_iter",
-            help="Maximum number of EM step",
+            help="Maximum number of EM steps",
             default=10000,
             type=int,
         )
@@ -220,7 +220,7 @@ def _define_parsers():
         param_grp.add_argument(
             "-ninitt",
             "--n_init_total_run",
-            help="Number of the best initializations that will be run\
+            help="Number of initializations that will be run\
             until convergence.",
             default=2,
             type=int,
@@ -228,7 +228,7 @@ def _define_parsers():
         param_grp.add_argument(
             "-t",
             "--tol",
-            help="Tolerance of likelihood to declare convergence.",
+            help="Tolerance on the likelihood to declare convergence.",
             default=1e-4,
             type=float,
         )
@@ -243,14 +243,14 @@ def _define_parsers():
         param_grp.add_argument(
             "-gpu",
             "--use_gpu",
-            help="Specify if a GPU should be used.",
+            help="Specifies whether a GPU should be used.",
             default=_DEFAULT_USE_GPU,
             type=bool,
         )
         param_grp.add_argument(
             "-idgpu",
             "--gpu_index",
-            help="Specify the gpu index if needed.",
+            help="Specifies the GPU index if needed.",
             default=None,
             type=bool,
         )
