@@ -48,33 +48,33 @@ def generate_LBM_dataset(  # pylint: disable=too-many-locals,too-many-branches,t
     verbosity: Optional[int] = 1,
     sparse: Optional[bool] = 1,
 ) -> dict:
-    """Generate a sparse bipartite graph with Latent Block Models.
+    """Generates a sparse bipartite graph from the Latent Block Model.
 
     Parameters
     ----------
     number_of_rows : int, optional, default : 2000
-        The number of nodes of type (1).
+        Number of type (1) nodes .
     number_of_columns : int, optional, default : 1000
-        The number of nodes of type (2).
+        Number of type (2) nodes.
     nb_row_clusters : int, optional, default : random between 3 and 5
-        The number of classes of nodes of type (1).
+        Number of classes of type (1) nodes.
     nb_column_clusters : int, default : random between 3 and 5
-        The number of classes of nodes of type (2).
+        Number of classes of type (2) nodes.
     connection_probabilities : np.ndarray, optional, default : random such as sparsity is 0.02
-        The probability of having an edge between the classes.
+        Probability of having an edge between classes.
     row_cluster_proportions : np.ndarray, optional, default : balanced
-        Proportion of the classes of nodes of type (1).
+        Class proportions for type (1) nodes.
     column_cluster_proportions : np.ndarray, optional, default : balanced
-        Proportion of the classes of nodes of type (2).
+        Class proportions for type (2) nodes.
     verbosity : int, optional, default : 1
         Display information during the generation process.
     sparse : bool, optional, default : True
-        Use the classical matrix generation and not the sparse one.
+        Use the sparse matrix generation instead of the classical one.
 
     Returns
     -------
     LBM_dataset
-        The generated dataset.
+        Generated dataset.
 
     Examples
     --------
@@ -229,32 +229,32 @@ def generate_SBM_dataset(  # pylint: disable=too-many-statements,too-many-branch
     symmetric: Optional[bool] = False,
     verbosity: Optional[int] = 1,
 ) -> SBM_dataset:
-    """Generate a sparse graph with Stochastic Block Models.
+    """Generates a sparse graph with the Stochastic Block Model.
 
     Parameters
     ----------
     number_of_nodes : int, optional, default : 1000
-        The number of nodes.
+        Number of nodes.
     number_of_clusters : int, optional, default : random between 3 and 5
-        The number of classes of nodes.
+        Number of node classes.
     connection_probabilities : np.ndarray, optional, default : see notes
-        The probability of having an edge between the classes.
+        Probability of having an edge between classes.
     cluster_proportions : np.ndarray, optional, default : balanced probabilies
-        Proportion of the classes of nodes.
+        Proportion of node classes.
     symmetric : bool, optional, default : False
-        Specify if the generated adjacency matrix is symmetric.
+        Specifies whether the generated adjacency matrix is symmetric.
     verbosity : int, optional, default : 1
-        Display information during the generation process.
+        Displays information during the generation process.
 
     Returns
     -------
     LBM_dataset
-        The generated dataset.
+        Generated dataset.
 
     Notes
     -----
     If no connection_probabilities is given, an affiliation graph is generated
-    with random probabilies on diagonal and such as the sparsity of the adjacency
+    with random probabilies on the diagonal and such that the sparsity of the adjacency
     matrix is 0.01.
 
     Examples
