@@ -51,8 +51,7 @@ except ImportError:
 
 class LBM(BaseEstimator):  # pylint: disable=too-many-instance-attributes
     """
-    LBM with distribution.
-    The class implements the random initialisation strategy.
+    LBM with Bernoulli distribution.
 
     Notes
     -----
@@ -95,31 +94,31 @@ class LBM(BaseEstimator):  # pylint: disable=too-many-instance-attributes
         Parameters
         ----------
         n_row_clusters : int
-            Number of row clusters to form
+            Number of row clusters in the model
         n_column_clusters : int
-            Number of row clusters to form
+            Number of row clusters in the model
         max_iter : int, optional
             Maximum number of EM iterations. Default: 10000.
         n_init : int, optional
-            Number of initializations that will be run for n_iter_early_stop EM
+            Number of initializations for the execution of the first n_iter_early_stop EM
             iterations. Default; 100.
         n_init_total_run : int, optional
-            Number of the n_init best initializations that will be run until
-            convergence. Default: 10.
+           Number of initializations that will be run until convergence
+            (best intermediate results among the n_init) . Default: 10.
         n_iter_early_stop : int, optional
-            Number of EM iterations to used to run the n_init initializations.
+            Number of EM iterations for the n_init initializations.
             Default 100.
         rtol : float
-            The relative tolerance parameter (see Notes). Default: 1e-10.
+            Relative tolerance parameter (see Notes). Default: 1e-10.
         atol : float
-            The absolute tolerance parameter (see Notes). Default: 1e-4.
+            Absolute tolerance parameter (see Notes). Default: 1e-4.
         verbosity : int, optional
             Degree of verbosity. Scale from 0 (no message displayed) to 3.
             Default 1.
         use_gpu : bool, optional
-            Specify if a GPU should be used. Default: _DEFAULT_USE_GPU.
+            Specifies whether a GPU should be used. Default: _DEFAULT_USE_GPU.
         gpu_index : int, optional
-            Specify the gpu index if needed.
+            Specifies the GPU index if needed.
         """
         self.max_iter = max_iter
         self.n_init = n_init
@@ -179,13 +178,13 @@ class LBM(BaseEstimator):  # pylint: disable=too-many-instance-attributes
 
     @property
     def column_predict_proba(self):
-        """array_like: Returns the predicted column classes membership probabilities"""
+        """array_like: Returns the predicted column class membership probabilities"""
         assert self.trained_successfully_, "Model not trained successfully"
         return self.tau_2_
 
     @property
     def trained_successfully(self):
-        """bool: Returns the predicted column classes membership probabilities"""
+        """bool: Returns the predicted column class membership probabilities"""
         return self.trained_successfully_
 
     def get_params(
@@ -234,7 +233,7 @@ class LBM(BaseEstimator):  # pylint: disable=too-many-instance-attributes
                 free_idx = GPUtil.getAvailable("memory", limit=10)
                 if not free_idx:
                     self.use_gpu = False
-                    logger.warning("GPU not used as no gpu is free")
+                    logger.warning("GPU not used as no GPU is free")
                 else:
                     self._np = cupy
                     self._cupyx = cupyx
@@ -269,7 +268,7 @@ class LBM(BaseEstimator):  # pylint: disable=too-many-instance-attributes
     def fit(  # pylint: disable=too-many-locals,too-many-branches,invalid-name,missing-type-doc,unused-argument
         self, X, _=None
     ) -> None:
-        """Perform co-clustering by direct maximization of graph modularity.
+        """Performs co-clustering by direct maximization of graph modularity.
 
         Parameters
         ----------
@@ -353,7 +352,7 @@ class LBM(BaseEstimator):  # pylint: disable=too-many-instance-attributes
             if self.verbosity > 0:
                 bar.finish()
                 logger.info(
-                    "---------- START TRAINING BEST INITIALIZATIONS ---------- "
+                    "----- CONTINUE TRAINING FOR THE BEST INITIALIZATIONS ----- "
                 )
                 bar = progressbar.ProgressBar(  # pylint: disable=blacklisted-name
                     max_value=len(best_inits),
@@ -428,7 +427,7 @@ class LBM(BaseEstimator):  # pylint: disable=too-many-instance-attributes
         in_place=False,
         run_number=None,
     ):
-        """Perform one run of the LBM algorithm with one random initialization.
+        """Runs the LBM algorithm once with a single random initialization.
 
         Parameters
         ----------
@@ -530,7 +529,7 @@ class LBM(BaseEstimator):  # pylint: disable=too-many-instance-attributes
         n1,
         n2,
     ):
-        """Realize EM step. Update both variationnal and model parameters.
+        """EM step. Updates both variationnal and model parameters.
 
         Parameters
         ----------
@@ -538,10 +537,10 @@ class LBM(BaseEstimator):  # pylint: disable=too-many-instance-attributes
             Matrix to be analyzed
         indices_ones : Non zero indices of the data matrix.
         pi : Connection probability matrix between row and column groups.
-        alpha_1 : Row group model parameters.
-        alpha_2 : Column group model parameters.
-        tau_1 : Row group variationnal parameters.
-        tau_2 : Column group variationnal parameters.
+        alpha_1 : Model parameters for row groups.
+        alpha_2 : Model parameters for column groups.
+        tau_1 : Variationnal parameters for row groups.
+        tau_2 : Variationnal parameters for column groups.
         n1 : Number of rows in the data matrix.
         n2 : Number of columns in the data matrix.
         """
@@ -616,10 +615,10 @@ class LBM(BaseEstimator):  # pylint: disable=too-many-instance-attributes
         ----------
         indices_ones : Non zero indices of the data matrix.
         pi : Connection probability matrix between row and column groups.
-        alpha_1 : Row group model parameters.
-        alpha_2 : Column group model parameters.
-        tau_1 : Row group variationnal parameters.
-        tau_2 : Column group variationnal parameters.
+        alpha_1 : Model parameters for row groups.
+        alpha_2 : Model parameters for column groups.
+        tau_1 : Variationnal parameters for row groups.
+        tau_2 : Variationnal parameters for column groups.
         """
         nq, nl = self.n_row_clusters, self.n_column_clusters
         return (
@@ -647,12 +646,12 @@ class LBM(BaseEstimator):  # pylint: disable=too-many-instance-attributes
         nl,
         nb_ones,
     ):
-        """Randomly initialize the LBM model and variationnal parameters.
+        """Randomly initializes the LBM model and variationnal parameters.
 
         Parameters
         ----------
-        n1 : number of rows of the data matrix.
-        n2 : number of column of the data matrix.
+        n1 : number of rows in the data matrix.
+        n2 : number of column in the data matrix.
         nq : number of row clusters.
         nl : number of column clusters.
         """
