@@ -58,7 +58,7 @@ except ImportError:
 
 class ModelSelection:  # pylint: disable=too-many-instance-attributes
     """
-    Explore and select the optimal number of classes for the LBM or SBM model.
+    Explores and selects the optimal number of classes for the LBM or SBM model.
     The best model is chosen according to the Integrated Completed Likelihood.
     A strategy of merging and splitting classes to produce good initializations is used.
 
@@ -100,15 +100,15 @@ class ModelSelection:  # pylint: disable=too-many-instance-attributes
         Parameters
         ----------
         model_type : {'LBM', 'SBM'}
-            The type of co-clustering model to use.
+            Type of co-clustering model to use.
         n_clusters_max : int, optional, default: 30
-            Upper limit of the number of classes.
+            Upper limit on the number of classes.
         use_gpu : bool, optional, default: True
-            Specify if a GPU should be used.
+            Specifies if a GPU should be used.
         gpu_index : int, optional, default: None
-            Specify the gpu index if needed.
+            Specifies the GPU index if needed.
         plot : bool, optional, default: True
-            Display model exploration plot.
+            Displays the model exploration plot.
 
         Raises
         ------
@@ -139,7 +139,7 @@ class ModelSelection:  # pylint: disable=too-many-instance-attributes
 
     @property
     def selection_result(self) -> ModelSelectionResults:
-        """ModelSelectionResults : Return a object representing explored models"""
+        """ModelSelectionResults : Returns an object representing explored models"""
         assert self.model_explored, "Model selection not trained. Use fit()"
         return ModelSelectionResults(
             {
@@ -159,19 +159,19 @@ class ModelSelection:  # pylint: disable=too-many-instance-attributes
         symmetric: Optional[bool] = False,
     ) -> ModelSelectionResults:
         # pylint: disable=line-too-long
-        """Perform model selection of the co-clustering.
+        """Performs model selection of the co-clustering.
 
         Parameters
         ----------
         graph : numpy.ndarray or scipy.sparse.spmatrix, shape=(n_samples, n_features) for the LBM or (n_samples, n_samples) for the SBM
             Matrix to be analyzed
         symmetric : bool, optional, default: False
-            In case of SBM model, specify if the graph connections are symmetric.
+            For the SBM model only, specifies if the graph connections are symmetric.
 
         Returns
         -------
         ModelSelectionResults
-           A object storing best model (according to ICL) and all trained models.
+           Object storing the best model (according to ICL) and all trained models.
 
         Raises
         ------
@@ -180,7 +180,7 @@ class ModelSelection:  # pylint: disable=too-many-instance-attributes
         """
         if self._model_type == "SBM" and graph.shape[0] != graph.shape[0]:
             raise ValueError(
-                "For SBM, graph shapes must be equals (n_samples, n_samples)."
+                "For SBM, graph sizes must be equals (n_samples, n_samples)."
             )
 
         # pylint: disable=attribute-defined-outside-init,invalid-name
@@ -275,7 +275,7 @@ class ModelSelection:  # pylint: disable=too-many-instance-attributes
 
     def _explore_strategy(self, strategy: str):
         # pylint: disable=too-many-statements,too-many-locals,too-many-branches,missing-return-type-doc,missing-return-doc
-        """Perform a splitting or merging strategy.
+        """Performs splitting merging strategies.
 
         The splitting strategy stops when the number of classes is greater
         than  min(1.5*number of classes of the best model,
@@ -286,7 +286,7 @@ class ModelSelection:  # pylint: disable=too-many-instance-attributes
         Parameters
         ----------
         strategy : {'merge', 'split'}
-            The type of strategy.
+            Type of strategy.
 
         Returns
         -------
@@ -347,7 +347,7 @@ class ModelSelection:  # pylint: disable=too-many-instance-attributes
                     logger.info("\t Already explored models from %s classes", nnq)
                     continue
             model_flag[flag_key] = True
-            logger.info("\t Explore models from %s classes", nnq)
+            logger.info("\t Explores models from %s classes", nnq)
 
             if self._model_type == "LBM":
                 # Explore all models derived from the strategy on the rows.
@@ -437,7 +437,7 @@ class ModelSelection:  # pylint: disable=too-many-instance-attributes
         classes and return the best one.
 
         The algorithm instantiate all merges/splits possible, n best models are
-        selected and trained for a few steps and the best of them is trained until
+        selected and trained for a few steps and the best one is trained until
         convergence.
 
         Parameters
