@@ -51,14 +51,13 @@ except ImportError:
 
 class SBM(BaseEstimator):  # pylint: disable=too-many-instance-attributes
     """
-    SBM with bernoulli distribution. The class implements the random
-    initialisation strategy.
+    SBM with Bernoulli distribution.
 
     Notes
     -----
     Convergence of the EM algorithm is declared when
     new_loglikelihood - old_loglikelihood <=
-    (`atol` + `rtol` * absolute(new_loglikelihood)). The convergence is checked
+    (`atol` + `rtol` * absolute(new_loglikelihood)). Convergence is checked
     every 5 EM steps.
 
     Examples
@@ -97,29 +96,29 @@ class SBM(BaseEstimator):  # pylint: disable=too-many-instance-attributes
         Parameters
         ----------
         n_clusters : int
-            Number of clusters to form
+            Number of clusters in the model
         max_iter : int, optional
             Maximum number of EM iterations. Default: 10000.
         n_init : int, optional
-            Number of initializations that will be run for n_iter_early_stop EM
+            Number of initializations for the execution of the first n_iter_early_stop EM
             iterations. Default: 100.
         n_init_total_run : int, optional
-            Number of the n_init best initializations that will be run until
-            convergence. Default: 10.
+            Number of initializations that will be run until convergence
+            (best intermediate results among the n_init) . Default: 10.
         n_iter_early_stop : int, optional
-            Number of EM iterations to used to run the n_init initializations.
+            Number of EM iterations for the n_init initializations.
             Default 100.
         rtol : float
-            The relative tolerance parameter (see Notes). Default 1e-10.
+            Relative tolerance parameter (see Notes). Default 1e-10.
         atol : float
-            The absolute tolerance parameter (see Notes). Default 1e-4.
+            Absolute tolerance parameter (see Notes). Default 1e-4.
         verbosity : int, optional
             Degree of verbosity. Scale from 0 (no message displayed) to 3.
             Default 1.
         use_gpu : bool, optional
-            Specify if a GPU should be used. Default: _DEFAULT_USE_GPU
+            Specifies whether a GPU should be used. Default: _DEFAULT_USE_GPU
         gpu_index : int, optional
-            Specify the gpu index if needed.
+            Specifies the GPU index if needed.
         """
         self.max_iter = max_iter
         self.n_init = n_init
@@ -193,7 +192,7 @@ class SBM(BaseEstimator):  # pylint: disable=too-many-instance-attributes
                 free_idx = GPUtil.getAvailable("memory", limit=10)
                 if not free_idx:
                     self.use_gpu = False
-                    logger.warning("GPU not used as no gpu is free")
+                    logger.warning("GPU not used as no GPU is free")
                 else:
                     self._np = cupy
                     self._cupyx = cupyx
@@ -220,21 +219,21 @@ class SBM(BaseEstimator):  # pylint: disable=too-many-instance-attributes
 
     @property
     def predict_proba(self):
-        """array_like: Returns the predicted classes membership probabilities"""
+        """array_like: Returns the predicted class membership probabilities"""
         assert self.trained_successfully_, "Model not trained successfully"
         return self.tau_
 
     @property
     def trained_successfully(self):
-        """bool: Returns the predicted column classes membership probabilities"""
+        """bool: Returns the predicted column class membership probabilities"""
         return self.trained_successfully_
 
     def get_ICL(self):  # pylint: disable=invalid-name
-        """Computation of the ICL criteria that can be used for model selection.
+        """Computation of the ICL criterion that can be used for model selection.
         Returns
         -------
         float
-            value of the ICL criteria.
+            value of the ICL criterion.
         """
         assert self.trained_successfully_, "Model must be trained successfully before"
         return (
@@ -250,14 +249,14 @@ class SBM(BaseEstimator):  # pylint: disable=too-many-instance-attributes
         _=None,
         symmetric=False,
     ):
-        """Perform co-clustering by direct maximization of graph modularity.
+        """Performs co-clustering by direct maximization of graph modularity.
 
         Parameters
         ----------
         X : scipy sparse matrix, shape=(n_nodes, n_nodes)
             Matrix to be analyzed
         symmetric : bool
-            Indicate if the adjacency matrix is symmetric (and a symmetric SBM
+            Indicates if the adjacency matrix is symmetric (and a symmetric SBM
             is used).
         """
         # pylint: disable=invalid-name,attribute-defined-outside-init
@@ -265,7 +264,7 @@ class SBM(BaseEstimator):  # pylint: disable=too-many-instance-attributes
         self._check_params()
         self.trained_successfully_ = False
         n, n2 = X.shape
-        assert n == n2, "Entry matrix is not squared"
+        assert n == n2, "Input matrix is not square"
         self._nb_rows = n
         X = sp.csr_matrix(X)
         X_t = sp.csr_matrix(X.T)
@@ -319,7 +318,7 @@ class SBM(BaseEstimator):  # pylint: disable=too-many-instance-attributes
             if self.verbosity > 0:
                 bar.finish()
                 logger.info(
-                    "---------- START TRAINING BEST INITIALIZATIONS ---------- "
+                    "----- CONTINUE TRAINING FOR THE BEST INITIALIZATIONS ----- "
                 )
                 bar = progressbar.ProgressBar(  # pylint: disable=blacklisted-name
                     max_value=len(best_inits),
@@ -377,7 +376,7 @@ class SBM(BaseEstimator):  # pylint: disable=too-many-instance-attributes
         in_place=False,
         run_number=None,
     ):
-        """Perform one run of the SBM algorithm with one random initialization.
+        """Runs the SBM algorithm once with a single random initialization.
 
         Parameters
         ----------
@@ -462,7 +461,7 @@ class SBM(BaseEstimator):  # pylint: disable=too-many-instance-attributes
         tau,
         n1,
     ):
-        """Realize EM step. Update both variationnal and model parameters.
+        """EM step. Updates both variationnal and model parameters.
 
         Parameters
         ----------
@@ -470,8 +469,8 @@ class SBM(BaseEstimator):  # pylint: disable=too-many-instance-attributes
             Matrix to be analyzed
         indices_ones : Non zero indices of the data matrix.
         pi : Connection probability matrix between row and column groups.
-        alpha : Group model parameters.
-        tau : Group variationnal parameters.
+        alpha : Model parameters for groups.
+        tau : Variationnal parameters for groups.
         n : Number of rows in the data matrix.
         """
         eps = max(1e-4 / n1, 1e-9)
@@ -535,7 +534,7 @@ class SBM(BaseEstimator):  # pylint: disable=too-many-instance-attributes
         alpha,
         tau,
     ):
-        """Compute the log-likelihood of the model with the given parameters.
+        """Computes the log-likelihood of the model with the given parameters.
 
         Parameters
         ----------
@@ -571,7 +570,7 @@ class SBM(BaseEstimator):  # pylint: disable=too-many-instance-attributes
         nq,
         nb_ones,
     ):
-        """Randomly initialize the SBM  model and variationnal parameters.
+        """Randomly initializes the SBM model and variationnal parameters.
 
         Parameters
         ----------
