@@ -56,7 +56,7 @@ def ARI(
         Ground truth class labels of the partition used as reference
 
     labels_pred : int array, shape = (n_samples,)
-        Cluster labels of the partition to evaluate
+        Cluster labels of the partition to be evaluated
 
 
     Returns
@@ -118,9 +118,9 @@ def CARI(
     labels_pred_part_1: Union[np.ndarray, list],
     labels_pred_part_2: Union[np.ndarray, list],
 ) -> float:
-    """Coclustering Adjusted Rand Index for two sets of biclusters.
+    """Coclustering Adjusted Rand Index for two sets of coclusters.
 
-    The Coclustering Adjuster Rand Index (CARI) computes a similarity measure
+    The Coclustering Adjusted Rand Index (CARI) computes a similarity measure
     between two coclusterings and is an adaptation of the
     Adjusted Rand Index (ARI) developed by Hubert and Arabie (1985) from a
     coclustering point of view.
@@ -136,10 +136,10 @@ def CARI(
         Ground truth class labels of the second partition used as reference
 
     labels_pred_part_1 : int array, shape = (n_samples_1,)
-        Cluster labels of the fist partition to evaluate
+        Cluster labels of the fist partition to be evaluated
 
     labels_pred_part_2 : int array, shape = (n_samples_2,)
-        Cluster labels of the second partition to evaluate
+        Cluster labels of the second partition to be evaluated
 
     Returns
     -------
@@ -238,25 +238,25 @@ def lbm_merge_group(
     idx_group_2: int,
     indices_ones: np.ndarray,
 ) -> Tuple[float, LBM]:
-    """Given a LBM model, returns the model obtained from the merge of the specified classes.
+    """Given an LBM model, returns the model obtained from the merge of the specified classes.
 
     Parameters
     ----------
     model : sparsebm.LBM
-        The model from which the merge is realized.
+        Model from which the merge is realized.
     idx_group_1 : int
-        index of the first row/column class to merge.
+        Index of the first row/column class to be merged.
     idx_group_2 : int
-        index of the second row/column class to merge.
+        Index of the second row/column class to be merged.
     type : int
-        0 for rows merging, 1 for columns merging.
+        0 for row merging, 1 for column merging.
     indices_ones : numpy.ndarray
         Indices of elements that are non-zero in the original data matrix.
 
     Returns
     -------
     tuple of (float, sparsebm.LBM)
-        The ICL value and the model obtained from the merge of two classes.
+        The ICL value and the model obtained from the merging of two classes.
 
     Raises
     ------
@@ -320,23 +320,23 @@ def sbm_merge_group(
     idx_group_2: int,
     indices_ones: np.ndarray,
 ) -> Tuple[float, SBM]:
-    """Given a SBM model, returns the model obtained from the merge of the specified classes.
+    """Given an SBM model, returns the model obtained from the merging of the specified classes.
 
     Parameters
     ----------
     model : sparsebm.SBM
-        The model from which the merge is realized.
+        Model from which the merge is realized.
     idx_group_1 : int
-        index of the first row/column class to merge.
+        Index of the first row/column class to be merged.
     idx_group_2 : int
-        index of the second row/column class to merge.
+        Index of the second row/column class to be merged.
     indices_ones : numpy.ndarray
         Indices of elements that are non-zero in the original data matrix.
 
     Returns
     -------
     tuple of (float, sparsebm.SBM)
-        The ICL value and the model obtained from the merge of two classes.
+        The ICL value and the model obtained from the merging of two classes.
     """
     # pylint: disable=invalid-name
     model.n_clusters -= 1
@@ -378,21 +378,21 @@ def lbm_split_group(
     index: int,
     indices_ones: np.array,
 ) -> Tuple[float, LBM]:
-    """Given a LBM model, returns the model obtained from the split of the specified class.
+    """Given an LBM model, returns the model obtained from the split of the specified class.
 
-    The specified class is splitted according to its median of degree.
+    The specified class is split according to its degree median.
 
     Parameters
     ----------
     model : sparsebm.LBM
-        The model from which the merge is realized.
+        Model from which the split is realized.
 
     row_col_degrees: tuple of numpy.ndarray
         Tuple of two arrays that contains the row and column degrees of the original data matrix
     type : int
         0 for rows splitting, 1 for columns splitting.
     index : int
-        index of the row/column class to split.
+        Index of the row/column class to be split.
     indices_ones : numpy.ndarray
         Indices of elements that are non-zero in the original data matrix.
 
@@ -464,18 +464,18 @@ def sbm_split_group(
     index: int,
     indices_ones: np.array,
 ):
-    """Given a SBM model, returns the model obtained from the split of the specified class.
+    """Given an SBM model, returns the model obtained from the split of the specified class.
 
-    The specified class is splitted according to its median of degree.
+    The specified class is split according to its degree median.
 
     Parameters
     ----------
     model : sparsebm.SBM
-        The model from which the merge is realized.
+        Model from which the merge is realized.
     degrees: numpy.ndarray
         Array that contains the degrees of the original data matrix.
     index : int
-        index of the class to split.
+        Index of the class to be split.
     indices_ones : numpy.ndarray
         Indices of elements that are non-zero in the original data matrix.
     Returns
@@ -528,7 +528,7 @@ def reorder_rows(  # pylint: disable=invalid-name,missing-param-doc
     Parameters
     ----------
     X : scipy.sparse.coo_matrix
-        The sparse matrix to reorder.
+        Sparse matrix to be reordered.
     idx: numpy.ndarray,  shape=(X.shape[0],)
         Row indices used to reorder the matrix.
     """
@@ -548,7 +548,7 @@ def reorder_cols(  # pylint: disable=invalid-name,missing-param-doc
     Parameters
     ----------
     X : scipy.sparse.coo_matrix
-        The sparse matrix to reorder.
+        Sparse matrix to be reordered.
     idx: numpy.ndarray,  shape=(X.shape[1],)
         Row indices used to reorder the matrix.
     """
@@ -568,7 +568,7 @@ def reorder_rows_and_cols(  # pylint: disable=invalid-name,missing-param-doc
     Parameters
     ----------
     X : scipy.sparse.coo_matrix
-        The sparse matrix to reorder. Must be square matrix.
+        Sparse matrix to be reordered. Must be square matrix.
     idx: numpy.ndarray,  shape=(X.shape[0],)
         Row indices used to reorder the matrix.
     """
